# Support

## Getting help

For usage questions:

- Read [README.md](README.md) first.
- Open a GitHub issue if you found a bug or want a feature.

## Before opening an issue

- Confirm you're on a recent `fsweep` version.
- Include exact command(s), flags, and terminal output.
- Include OS and environment details.

## Security issues

Report vulnerabilities privately through:

<https://github.com/drew-simmons/fsweep/security/advisories/new>
